@@ -2,8 +2,8 @@ from Testing import ZopeTestCase
 from Products.PloneTestCase import PloneTestCase
 
 import Products.ATVocabularyManager
-from Products.ATVocabularyManager.config import *
 
+from Products.ATVocabularyManager.config import *
 
 from Products.Five import zcml
 from Products.Five import fiveconfigure
@@ -12,36 +12,25 @@ from Products.PloneTestCase import PloneTestCase as ptc
 from Products.PloneTestCase.layer import onsetup
 from Products.CMFCore.utils import getToolByName
 
-
-
-
-PloneTestCase.setupPloneSite(id='plone')
-
 @onsetup
 def installProducts():
-    ZopeTestCase.installProduct('Archetypes')
-    ZopeTestCase.installProduct('MimetypesRegistry')
-    ZopeTestCase.installProduct('PortalTransforms')
-    # to support tests for translated vocabularies
-    ZopeTestCase.installProduct('PloneLanguageTool')
-    ZopeTestCase.installProduct('LinguaPlone')
-
-
     fiveconfigure.debug_mode = True
-    zcml.load_config('configure.zcml',
-                     Products.ATVocabularyManager)
+    zcml.load_config('configure.zcml', Products.ATVocabularyManager)
     fiveconfigure.debug_mode = False
-        
-    ZopeTestCase.installProduct(PROJECTNAME)
-
 
+PloneTestCase.setupPloneSite(id='plone')
 installProducts()
+ZopeTestCase.installProduct('Archetypes')
+ZopeTestCase.installProduct('MimetypesRegistry')
+ZopeTestCase.installProduct('PortalTransforms')
+# to support tests for translated vocabularies
+ZopeTestCase.installProduct('PloneLanguageTool')
+ZopeTestCase.installProduct('LinguaPlone')
+ZopeTestCase.installProduct(PROJECTNAME)
 
 def installWithinPortal(portal):
-    
     qi = getToolByName(portal, 'portal_quickinstaller')
     qi.installProduct(PROJECTNAME)
 
-
 def getATVM(portal):
     return portal[TOOL_NAME]
